@@ -6,12 +6,15 @@ const _path = _interopRequireDefault(require('path'));
 
 module.exports = Ferdium => {
   const getMessages = () => {
-    let unread = 0;
-    const notificationBadge = document.querySelectorAll('.unreadcount')[0];
-    if (notificationBadge !== undefined) {
-      unread = Ferdium.safeParseInt(notificationBadge.textContent);
+    let count = 0;
+    const element = document.querySelector(
+      '.dashboard-top-panel .indicators .stats-group .cell-value',
+    );
+    if (element) {
+      count = Ferdium.safeParseInt(element.textContent);
     }
-    Ferdium.setBadge(unread);
+
+    Ferdium.setBadge(count);
   };
 
   Ferdium.loop(getMessages);
